You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@sling.apache.org by cz...@apache.org on 2009/06/24 07:44:43 UTC

svn commit: r787912 - /sling/trunk/bundles/api/src/main/java/org/apache/sling/api/resource/ResourceProvider.java

Author: cziegeler
Date: Wed Jun 24 05:44:43 2009
New Revision: 787912

URL: http://svn.apache.org/viewvc?rev=787912&view=rev
Log:
Fix javadoc

Modified:
    sling/trunk/bundles/api/src/main/java/org/apache/sling/api/resource/ResourceProvider.java

Modified: sling/trunk/bundles/api/src/main/java/org/apache/sling/api/resource/ResourceProvider.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/api/src/main/java/org/apache/sling/api/resource/ResourceProvider.java?rev=787912&r1=787911&r2=787912&view=diff
==============================================================================
--- sling/trunk/bundles/api/src/main/java/org/apache/sling/api/resource/ResourceProvider.java (original)
+++ sling/trunk/bundles/api/src/main/java/org/apache/sling/api/resource/ResourceProvider.java Wed Jun 24 05:44:43 2009
@@ -22,6 +22,8 @@
 
 import javax.servlet.http.HttpServletRequest;
 
+import org.apache.sling.api.SlingException;
+
 /**
  * API for providers of resources. Used by the {@link ResourceResolver} to
  * transparently access resources from different locations such as a JCR
@@ -51,7 +53,7 @@
      * {@link #listChildren(Resource)} method to enable traversing the resource
      * tree down to a deeply nested provided resource which has no concrete
      * parent hierarchy (value is"sling:syntheticResourceProviderResource").
-     * 
+     *
      * @see #listChildren(Resource)
      */
     static final String RESOURCE_TYPE_SYNTHETIC = "sling:syntheticResourceProviderResource";
@@ -66,12 +68,12 @@
      * parametrize the resource resolution. An example of such parametrization
      * is support for a JSR-311 style resource provider to support the
      * parametrized URL patterns.
-     * 
+     *
      * @param resourceResolver The {@link ResourceResolver} to which the
      *            returned {@link Resource} is attached.
      * @return <code>null</code> If this provider does not have a resource for
      *         the path.
      * @throws SlingException may be thrown in case of any problem creating the
      *             <code>Resource</code> instance.
      */
     Resource getResource(ResourceResolver resourceResolver,
@@ -81,12 +83,12 @@
      * Returns a resource from this resource provider or <code>null</code> if
      * the resource provider cannot find it. The path should have one of the
      * {@link #ROOTS} strings as its prefix.
-     * 
+     *
      * @param resourceResolver The {@link ResourceResolver} to which the
      *            returned {@link Resource} is attached.
      * @return <code>null</code> If this provider does not have a resource for
      *         the path.
      * @throws SlingException may be thrown in case of any problem creating the
      *             <code>Resource</code> instance.
      */
     Resource getResource(ResourceResolver resourceResolver, String path);
@@ -106,7 +108,7 @@
      * exist but are required to traverse the resource tree. Such resources
      * SHOULD be {@link SyntheticResource} objects whose resource type MUST be
      * set to {@link #RESOURCE_TYPE_SYNTHETIC}.
-     * 
+     *
      * @param parent The {@link Resource Resource} whose children are requested.
      * @return An <code>Iterator</code> of {@link Resource} objects or
      *         <code>null</code> if the resource provider has no children for
@@ -66,12 +68,12 @@
      * @return <code>null</code> If this provider does not have a resource for
      *         the path.
-     * @throws SlingException may be thrown in case of any problem creating the
+     * @throws org.apache.sling.api.SlingException may be thrown in case of any problem creating the
      *             <code>Resource</code> instance.
      */
@@ -81,12 +83,12 @@
      * @return <code>null</code> If this provider does not have a resource for
      *         the path.
-     * @throws SlingException may be thrown in case of any problem creating the
+     * @throws org.apache.sling.api.SlingException may be thrown in case of any problem creating the
      *             <code>Resource</code> instance.
      */